@@ -1,19 +1,10 @@
-/***************************************************************************
-             filter_lnotes.cxx  -  Lotus Notes Structured Text mail import
-                             -------------------
-    begin                : Wed Feb 16, 2005
-    copyright            : (C) 2005 by Robert Rockers
-    email                : kconfigure@rockerssoft.com
- ***************************************************************************/
+/*
+  filterlnotes.cpp  -  Lotus Notes Structured Text mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2005 Robert Rockers <kconfigure@rockerssoft.com>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterlnotes.h"
 
@@ -26,10 +17,6 @@ using namespace MailImporter;
 class MailImporter::FilterLNotesPrivate
 {
 public:
-    FilterLNotesPrivate()
-    {
-    }
-
     /** the working directory */
     QDir dir;
     /** which file (of d->totalFiles) is now in the work? */
@@ -54,10 +41,7 @@ FilterLNotes::FilterLNotes()
 }
 
 /** Destructor. */
-FilterLNotes::~FilterLNotes()
-{
-    delete d;
-}
+FilterLNotes::~FilterLNotes() = default;
 
 /**
  * Recursive import of The Bat! maildir.
@@ -139,7 +123,6 @@ void FilterLNotes::ImportLNotes(const QString &file)
                     // close file, send it
                     tempfile->close();
 
-
                     if (!importMessage(folder, tempfile->fileName(), filterInfo()->removeDupMessage())) {
                         filterInfo()->addErrorLogEntry(i18n("Could not import %1", tempfile->fileName()));
                     }
